#ifndef _CosTypedEventComm_IDL_
#define _CosTypedEventComm_IDL_

#pragma prefix "omg.org"

#include "CosEventComm.idl"

module CosTypedEventComm {
	interface TypedPushConsumer: CosEventComm::PushConsumer {
		Object get_typed_consumer();
	};

	interface TypedPullSupplier: CosEventComm::PullSupplier {
		Object get_typed_supplier();
	};
};

#endif /* !_CosTypedEventComm_IDL_ */
