#ifndef ORBITUTIL_OS_SPECIFICS_H
#define ORBITUTIL_OS_SPECIFICS_H 1

#include <ORBitutil/orbit-os-config.h>

#include <ORBitutil/os-feature-alloca.h>

/* This file should be a bunch of #ifdef's to #include the
   os-<osname>.h for the current OS.  It is intended to abstract the
   gunkiness necessary to get some OS's to build ORBit properly. */

#endif
