/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */
#ifndef ORB_CONFIG_H
#define ORB_CONFIG_H 1

/* When creating a memory pool for a particular type, how many chunks
   do we want to pre-allocated? */
#define ORBIT_CHUNKS_PREALLOC 2

#endif /* ORB_CONFIG_H */
